@@ -32,10 +32,9 @@ class ShuangpinProfilePrivate;
 
 class LIBIMEPINYIN_EXPORT ShuangpinProfile {
 public:
-    typedef std::map<std::string,
-                     std::multimap<PinyinSyllable, PinyinFuzzyFlags>>
-        TableType;
-    typedef std::set<char> ValidInputSetType;
+    using TableType =
+        std::map<std::string, std::multimap<PinyinSyllable, PinyinFuzzyFlags>>;
+    using ValidInputSetType = std::set<char>;
     explicit ShuangpinProfile(ShuangpinBuiltinProfile profile);
     explicit ShuangpinProfile(std::istream &in);
 
@@ -43,6 +42,7 @@ public:
 
     const TableType &table() const;
     const ValidInputSetType &validInput() const;
+    const ValidInputSetType &validInitial() const;
 
 private:
     void buildShuangpinTable();
